/**
 * Walking parsed trees.
 * @author Louis-Dominique Dubeau
 * @license MPL 2.0
 * @copyright Mangalam Research Center for Buddhist Languages
 */
import { Element } from "./parser";
/**
 * Base class for conversion walkers.
 */
export declare abstract class ConversionWalker {
    /**
     * Walks an element's children.
     *
     * @param el The element whose children must be walked.
     *
     * @param startAt Index at which to start walking.
     *
     * @param endAt Index at which to end walking. If unspecified, go to the end
     * of the children of ``el``.
     */
    walkChildren(el: Element, startAt?: number, endAt?: number): void;
    /**
     * Walk an element.
     *
     * @param el The element to walk.
     */
    abstract walk(el: Element): void;
}
