"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/**
 * A resource loader that loads resources using Node's ``fs`` facilities or
 * ``fetch``.
 *
 * @author Louis-Dominique Dubeau
 * @license MPL 2.0
 * @copyright Mangalam Research Center for Buddhist Languages
 */
const fs = tslib_1.__importStar(require("fs"));
const fetch_1 = require("./fetch");
class NodeResource {
    constructor(url, text) {
        this.url = url;
        this.text = text;
    }
    getText() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.text;
        });
    }
}
exports.NodeResource = NodeResource;
/**
 * A resource loader that loads resources using Node's ``fs`` facilities or
 * ``fetch``.
 *
 * URLs with the file: protocol are loaded through Node's ``fs``
 * facilities. Otherwise, fetch is used.
 */
class NodeResourceLoader {
    constructor() {
        // We use composition to delegate network loads to the fetch loader. Extending
        // FetchResourceLoader causes interface complications.
        this.fetchLoader = new fetch_1.FetchResourceLoader();
    }
    load(url) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (url.protocol === "file:") {
                // We convert it back to a path because we need to support Node prior to
                // version 8. Only version 8 and above allows passing a file:// URL
                // directly to fs functions.
                const asString = url.toString().replace(/^file:\/\//, "");
                return new Promise((resolve, reject) => {
                    fs.readFile(asString, (err, data) => {
                        if (err != null) {
                            reject(err);
                            return;
                        }
                        resolve(new NodeResource(url, data.toString()));
                    });
                });
            }
            return this.fetchLoader.load(url);
        });
    }
}
exports.NodeResourceLoader = NodeResourceLoader;
//# sourceMappingURL=node.js.map